/* cookie plugin */
/*!
 * jQuery CooQuery Plugin v2
 * http://cooquery.lenonmarcel.com.br/
 *
 * Copyright 2009, 2010 Lenon Marcel
 * Dual licensed under the MIT and GPL licenses.
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 * Date: 2010-01-24 (Sun, 24 January 2010)
 */
(function($){
  $.setCookie = function( name, value, options ){
    if( typeof name === 'undefined' || typeof value === 'undefined' )
      return false;

    var str = name + '=' + encodeURIComponent(value);

    if( options.domain ) str += '; domain=' + options.domain;
    if( options.path ) str += '; path=' + options.path;
    if( options.duration ){
      var date = new Date();
      date.setTime( date.getTime() + options.duration * 24 * 60 * 60 * 1000 );
      str += '; expires=' + date.toGMTString();
    }
    if( options.secure ) str += '; secure';

    return document.cookie = str;
  };

  $.delCookie = function( name ){
    return $.setCookie( name, '', { duration: -1 } );
  };

  // Based on Mootools Cookie.read function (http://mootools.net/docs/core/Utilities/Cookie#Cookie:read)
  $.readCookie = function( name ){
    var value = document.cookie.match('(?:^|;)\\s*' + name.replace(/([-.*+?^${}()|[\]\/\\])/g, '\\$1') + '=([^;]*)');
    return (value) ? decodeURIComponent(value[1]) : null;
  };

  $.CooQueryVersion = 'v 2.0';
})(jQuery);

var PmailerUtilities = {};

PmailerUtilities.Form =
{
	subscribe: function(event)
	{
		event.preventDefault();
		jQuery('#pmailer_sub_form_status').show();
		// dont allow form to be submitted mutliple times
		jQuery('#pmailer_subscription_submit').attr('disabled', 'disabled');
		jQuery('#pmailer_sub_form_error, #pmailer_sub_form_success').html('');
		
		// submit form
		var pmailer_sub_url = jQuery('#pmailer_sub_ajax_url').val();
		var params = jQuery('#pmailer_subscription_form').serialize();
		jQuery.post(pmailer_sub_url, params, function(data) 
		{
			// clear previous messages
			jQuery('#pmailer_sub_form_success, #pmailer_sub_form_error').html('').hide();
			
			// check if subscribe was succesfull
			var response = jQuery.parseJSON(data);
			if ( response.status == 'success' )
			{
				jQuery('#pmailer_subscription_submit').removeAttr('disabled');
				jQuery('#pmailer_sub_smart_form_status').hide();
				jQuery('#pmailer_sub_form_success').html('Email address successfully subscribed.<br />').show();
				jQuery('#pmailer_sub_form_status').hide();
				jQuery('#pmailer_subscription_form input[type|="text"]').val(''); // clear form
				jQuery('#pmailer_subscription_form input[type|="checkbox"]').removeAttr('checked'); 
			}
			
			// check if errors occurred
			if ( response.status == 'error' )
			{
				jQuery('#pmailer_sub_smart_form_status').hide();
				jQuery('#pmailer_subscription_submit').removeAttr('disabled');
				// warn if email address was not filled in
				if ( response.message.indexOf('required') > 1 && response.message.indexOf('set') > 1 )
				{
					jQuery('#pmailer_sub_form_error').html('Email address was not filled in.<br />').show();
				}
				
				// warn if email address was not valid
				if ( response.message.indexOf('validating') > 1 && response.message.indexOf('valid email') > 1 || response.message.indexOf('valid hostname') > 1 )
				{
					jQuery('#pmailer_sub_form_error').html('Invalid email address.<br />').show();
				}
				
				// warn no lists were selected
				if ( response.message.indexOf('lists') > 1 && response.message.indexOf('chosen') > 1 )
				{
					jQuery('#pmailer_sub_form_error').html('No lists were chosen.<br />').show();
				}
				
				jQuery('#pmailer_sub_form_status').hide();
			}
		});
		
	}
};

/* pmailer submission form logic */
(function($)
{
	// do nothing if jquery does not exist
	if (!jQuery)
	{
		return;
	}
	$(document).ready(function() 
    {
		// check if pmailer form widget is to be ajaxed and bind appropriate events
		if ( jQuery('#pmailer_sub_ajax_form').val() == 'yes' )
		{
			jQuery('#pmailer_subscription_submit').bind('click', PmailerUtilities.Form.subscribe);
		}
		
		// check if smart forms is enabled
		if( jQuery('#pmailer_sub_smart_form_enabled').val() != 'yes' )
		{
			return;
		}
		
		// check if user has chosen not to see smart form
		if ( $.readCookie('pmailer_show_smart_form') == 'false' )
		{
			return;
		}
		
		// create cookie if it does not exist
		if ( $.readCookie('pmailer_page_views') == null )
		{
			$.setCookie( 'pmailer_page_views', '0', {
			    duration : 60 // In days
			});
		}
		else // increment page view 
		{
			var page_views = parseInt($.readCookie('pmailer_page_views'));
			page_views = page_views + 1;
			
			$.setCookie('pmailer_page_views', page_views, 
			{
			    duration : 365 // In days
			});
			
			// display smart form if page views is over 5
			var show_smart_form = $.readCookie('pmailer_show_smart_form');
			if ( show_smart_form != 'false' && page_views >= parseInt($('#pmailer_sub_smart_form_page_view_activation').val()) )
			{
				var pmailer_dialogue_title = $('#pmailer_dialogue_heading').html();
				jQuery('#pmailer_smart_form').show();
				jQuery('#pmailer_smart_form').dialog(
		        {
		        	minHeight:200,
		            title: pmailer_dialogue_title,
		            modal: true,
		            resizable: false,
		            close: PmailerUtilities.Dialog.close,
		            buttons:
		            [
		                {
		                    text: "Do not show again",
		                    click: PmailerUtilities.Dialog.close
		                },
		                {
		                    text: $('#pmailer_subscription_smart_submit').val(),
		                    click: PmailerUtilities.Dialog.subscribe,
		                    id: 'pmailer_sub_smart_subscribe'
		                }
		            ]
		        });

			}
		}
	
    });
	
})(jQuery);

PmailerUtilities.Dialog =
{
	close: function(event)
	{
		// if user closed dialogue reset page view cookie
		if (event.type == "dialogclose")
		{
			jQuery.setCookie('pmailer_page_views', 0, 
			{
			    duration : 365 // In days
			});
		}
		else // the user clicked the do not show again btn
		{
			jQuery('#pmailer_smart_form').dialog('destroy');
			jQuery.setCookie('pmailer_show_smart_form', 'false', 
			{
				duration : 365 // In days
			});
			// cleanup un-needed cookie
			jQuery.delCookie('pmailer_page_views');
		}
	},
	
	subscribe: function(event)
	{
		// hide previous error message
		jQuery('#pmailer_sub_smart_form_error').hide();
		// display subscribing text while ajax request is being made.
		jQuery('#pmailer_sub_smart_form_status').show();
		// disable subscribe btn
		jQuery('#pmailer_sub_smart_subscribe').attr('disabled', 'disabled');
		var pmailer_sub_url = jQuery('#pmailer_sub_smart_ajax_url').val();
		var params = jQuery('#pmailer_subscription_smart_form').serialize();
		jQuery.post(pmailer_sub_url, params, function(data) 
		{
			// check if subscribe was succesfull
			var response = jQuery.parseJSON(data);
			if ( response.status == 'success' )
			{
				jQuery('#pmailer_sub_smart_form_status').hide();
				jQuery('#pmailer_subscription_smart_form').html('<span class="pmailer_subscription_success">Email address successfully subscribed.</span>').show();
				window.setTimeout("jQuery('#pmailer_smart_form').dialog('close'); jQuery('#pmailer_sub_smart_subscribe').removeAttr('disabled');", 3000);
				// do not display the smart form again
				jQuery.setCookie('pmailer_show_smart_form', 'false', 
				{
					duration : 365 // In days
				});
			}
			
			// check if errors occurred
			if ( response.status == 'error' )
			{
				jQuery('#pmailer_sub_smart_form_status').hide();
				jQuery('#pmailer_sub_smart_subscribe').removeAttr('disabled');
				// warn if email address was not filled in
				if ( response.message.indexOf('required') > 1 && response.message.indexOf('set') > 1 )
				{
					jQuery('#pmailer_sub_smart_form_error').html('Email address was not filled in.<br />').show();
				}
				
				// warn if email address was not valid
				if ( response.message.indexOf('validating') > 1 && response.message.indexOf('valid email') > 1 || response.message.indexOf('valid hostname') > 1 )
				{
					jQuery('#pmailer_sub_smart_form_error').html('Invalid email address.<br />').show();
				}
				
				// warn no lists were selected
				if ( response.message.indexOf('lists') > 1 && response.message.indexOf('chosen') > 1 )
				{
					jQuery('#pmailer_sub_smart_form_error').html('No lists were chosen.<br />').show();
				}
			}
			
		});
		
		
	}
};

